@@ -4,6 +4,8 @@ import (
 	"github.com/git-town/git-town/v16/internal/cli/dialog/components"
 	"github.com/git-town/git-town/v16/internal/config/configdomain"
 	"github.com/git-town/git-town/v16/internal/git/gitdomain"
+	"github.com/git-town/git-town/v16/internal/hosting/hostingdomain"
+	. "github.com/git-town/git-town/v16/pkg/prelude"
 )
 
 // Lineage validates that the given lineage contains the ancestry for all given branches.
@@ -22,6 +24,17 @@ func Lineage(args LineageArgs) (additionalLineage configdomain.Lineage, addition
 			branchesToVerify = append(branchesToVerify, parent)
 			continue
 		}
+		// look for parent in proposals
+		if connector, hasConnector := args.Connector.Get(); hasConnector {
+			proposalOpt, _ := connector.SearchProposals(branchToVerify)
+			if proposal, hasProposal := proposalOpt.Get(); hasProposal {
+				parent := proposal.Target
+				additionalLineage.Add(branchToVerify, parent)
+				branchesToVerify = append(branchesToVerify, parent)
+				continue
+			}
+		}
+		// ask for parent
 		outcome, selectedBranch, err := Parent(ParentArgs{
 			Branch:          branchToVerify,
 			DefaultChoice:   args.DefaultChoice,
@@ -50,6 +63,7 @@ type LineageArgs struct {
 	BranchesAndTypes configdomain.BranchesAndTypes
 	BranchesToVerify gitdomain.LocalBranchNames
 	Config           configdomain.UnvalidatedConfig
+	Connector        Option[hostingdomain.Connector]
 	DefaultChoice    gitdomain.LocalBranchName
 	DialogTestInputs components.TestInputs
 	LocalBranches    gitdomain.LocalBranchNames
