@@ -1,7 +1,6 @@
 package dialog
 
 import (
-	"slices"
 	"strings"
 
 	tea "github.com/charmbracelet/bubbletea"
@@ -19,32 +18,16 @@ type SwitchBranchEntry struct {
 	Branch        gitdomain.LocalBranchName
 	Indentation   string
 	OtherWorktree bool
+	Type          configdomain.BranchType
 }
 
 func (sbe SwitchBranchEntry) String() string {
 	return sbe.Indentation + sbe.Branch.String()
 }
 
-func SwitchBranch(localBranches gitdomain.LocalBranchNames, branchTypes []configdomain.BranchType, branchesAndTypes configdomain.BranchesAndTypes, initialBranch gitdomain.LocalBranchName, lineage configdomain.Lineage, allBranches gitdomain.BranchInfos, uncommittedChanges bool, inputs components.TestInput) (gitdomain.LocalBranchName, bool, error) {
-	entries := SwitchBranchEntries(localBranches, branchTypes, branchesAndTypes, lineage, allBranches)
-	cursor := SwitchBranchCursorPos(entries, initialBranch)
-	dialogProgram := tea.NewProgram(SwitchModel{
-		InitialBranchPos:   cursor,
-		List:               list.NewList(newSwitchBranchListEntries(entries), cursor),
-		UncommittedChanges: uncommittedChanges,
-	})
-	components.SendInputs(inputs, dialogProgram)
-	dialogResult, err := dialogProgram.Run()
-	if err != nil {
-		return "", false, err
-	}
-	result := dialogResult.(SwitchModel) //nolint:forcetypeassert
-	selectedData := result.List.SelectedData()
-	return selectedData.Branch, result.Aborted(), nil
-}
-
 type SwitchModel struct {
 	list.List[SwitchBranchEntry]
+	DisplayBranchTypes configdomain.DisplayTypes
 	InitialBranchPos   int  // position of the currently checked out branch in the list
 	UncommittedChanges bool // whether the workspace has uncommitted changes
 }
@@ -73,10 +56,10 @@ func (self SwitchModel) Update(msg tea.Msg) (tea.Model, tea.Cmd) { //nolint:iret
 }
 
 func (self SwitchModel) View() string {
+	s := strings.Builder{}
 	if self.Status != list.StatusActive {
 		return ""
 	}
-	s := strings.Builder{}
 	if self.UncommittedChanges {
 		s.WriteString("\n")
 		s.WriteString(colors.BoldCyan().Styled(messages.SwitchUncommittedChanges))
@@ -113,6 +96,10 @@ func (self SwitchModel) View() string {
 			}
 			s.WriteString(color.Styled("  " + entry.Text))
 		}
+		if self.DisplayBranchTypes.IsTrue() && ShouldDisplayBranchType(entry.Data.Type) {
+			s.WriteString("  ")
+			s.WriteString(colors.Faint().Styled("(" + entry.Data.Type.String() + ")"))
+		}
 		s.WriteRune('\n')
 	}
 	s.WriteString("\n\n  ")
@@ -151,59 +138,31 @@ func (self SwitchModel) View() string {
 	return s.String()
 }
 
-// SwitchBranchCursorPos provides the initial cursor position for the "switch branch" components.
-func SwitchBranchCursorPos(entries []SwitchBranchEntry, initialBranch gitdomain.LocalBranchName) int {
-	for e, entry := range entries {
-		if entry.Branch == initialBranch {
-			return e
-		}
+func ShouldDisplayBranchType(branchType configdomain.BranchType) bool {
+	switch branchType {
+	case configdomain.BranchTypeMainBranch, configdomain.BranchTypeFeatureBranch:
+		return false
+	case configdomain.BranchTypeContributionBranch, configdomain.BranchTypeObservedBranch, configdomain.BranchTypeParkedBranch, configdomain.BranchTypePerennialBranch, configdomain.BranchTypePrototypeBranch:
+		return true
 	}
-	return 0
+	panic("unhandled branch type:" + branchType.String())
 }
 
-// SwitchBranchEntries provides the entries for the "switch branch" components.
-func SwitchBranchEntries(localBranches gitdomain.LocalBranchNames, branchTypes []configdomain.BranchType, branchesAndTypes configdomain.BranchesAndTypes, lineage configdomain.Lineage, allBranches gitdomain.BranchInfos) []SwitchBranchEntry {
-	entries := make([]SwitchBranchEntry, 0, lineage.Len())
-	roots := lineage.Roots()
-	// add all entries from the lineage
-	for _, root := range roots {
-		layoutBranches(&entries, root, "", lineage, allBranches, branchTypes, branchesAndTypes)
-	}
-	// add missing local branches
-	branchesInLineage := lineage.Branches()
-	for _, localBranch := range localBranches {
-		if slices.Contains(roots, localBranch) {
-			continue
-		}
-		if slices.Contains(branchesInLineage, localBranch) {
-			continue
-		}
-		layoutBranches(&entries, localBranch, "", lineage, allBranches, branchTypes, branchesAndTypes)
-	}
-	return entries
-}
-
-// layoutBranches adds entries for the given branch and its children to the given entry list.
-// The entries are indented according to their position in the given lineage.
-func layoutBranches(result *[]SwitchBranchEntry, branch gitdomain.LocalBranchName, indentation string, lineage configdomain.Lineage, allBranches gitdomain.BranchInfos, branchTypes []configdomain.BranchType, branchesAndTypes configdomain.BranchesAndTypes) {
-	if allBranches.HasLocalBranch(branch) || allBranches.HasMatchingTrackingBranchFor(branch) {
-		var otherWorktree bool
-		if branchInfo, hasBranchInfo := allBranches.FindByLocalName(branch).Get(); hasBranchInfo {
-			otherWorktree = branchInfo.SyncStatus == gitdomain.SyncStatusOtherWorktree
-		} else {
-			otherWorktree = false
-		}
-		branchType, hasBranchType := branchesAndTypes[branch]
-		if !hasBranchType && len(branchTypes) > 0 {
-			panic("cannot determine branch type for branch: " + branch)
-		}
-		if len(branchTypes) == 0 || slices.Contains(branchTypes, branchType) {
-			*result = append(*result, SwitchBranchEntry{Branch: branch, Indentation: indentation, OtherWorktree: otherWorktree})
-		}
-	}
-	for _, child := range lineage.Children(branch) {
-		layoutBranches(result, child, indentation+"  ", lineage, allBranches, branchTypes, branchesAndTypes)
+func SwitchBranch(entries []SwitchBranchEntry, cursor int, uncommittedChanges bool, displayTypes configdomain.DisplayTypes, inputs components.TestInput) (gitdomain.LocalBranchName, bool, error) {
+	dialogProgram := tea.NewProgram(SwitchModel{
+		DisplayBranchTypes: displayTypes,
+		InitialBranchPos:   cursor,
+		List:               list.NewList(newSwitchBranchListEntries(entries), cursor),
+		UncommittedChanges: uncommittedChanges,
+	})
+	components.SendInputs(inputs, dialogProgram)
+	dialogResult, err := dialogProgram.Run()
+	if err != nil {
+		return "", false, err
 	}
+	result := dialogResult.(SwitchModel) //nolint:forcetypeassert
+	selectedData := result.List.SelectedData()
+	return selectedData.Branch, result.Aborted(), nil
 }
 
 func newSwitchBranchListEntries(switchBranchEntries []SwitchBranchEntry) list.Entries[SwitchBranchEntry] {
