@@ -4,10 +4,10 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/git-town/git-town/v15/internal/cli/dialog/components"
-	"github.com/git-town/git-town/v15/internal/cli/dialog/components/list"
-	"github.com/git-town/git-town/v15/internal/config/configdomain"
-	"github.com/git-town/git-town/v15/internal/messages"
+	"github.com/git-town/git-town/v16/internal/cli/dialog/components"
+	"github.com/git-town/git-town/v16/internal/cli/dialog/components/list"
+	"github.com/git-town/git-town/v16/internal/config/configdomain"
+	"github.com/git-town/git-town/v16/internal/messages"
 )
 
 const (
@@ -29,11 +29,11 @@ const (
 )
 
 func SyncFeatureStrategy(existing configdomain.SyncFeatureStrategy, inputs components.TestInput) (configdomain.SyncFeatureStrategy, bool, error) {
-	entries := list.NewEntries(
+	entries := []syncFeatureStrategyEntry{
 		syncFeatureStrategyEntryMerge,
 		syncFeatureStrategyEntryRebase,
 		syncFeatureStrategyEntryCompress,
-	)
+	}
 	var defaultPos int
 	switch existing {
 	case configdomain.SyncFeatureStrategyMerge:
@@ -51,7 +51,7 @@ func SyncFeatureStrategy(existing configdomain.SyncFeatureStrategy, inputs compo
 	}
 	cutSelection, _, _ := strings.Cut(selection.String(), " ")
 	fmt.Printf(messages.SyncFeatureBranches, components.FormattedSelection(cutSelection, aborted))
-	return selection.Data.SyncFeatureStrategy(), aborted, err
+	return selection.SyncFeatureStrategy(), aborted, err
 }
 
 type syncFeatureStrategyEntry string
