@@ -1,7 +1,7 @@
 package flags
 
 import (
-	"github.com/git-town/git-town/v15/internal/config/configdomain"
+	"github.com/git-town/git-town/v16/internal/config/configdomain"
 	"github.com/spf13/cobra"
 )
 
@@ -10,7 +10,7 @@ const noPushLong = "no-push"
 // type-safe access to the CLI arguments of type gitdomain.NoPush
 func NoPush() (AddFunc, ReadNoPushFlagFunc) {
 	addFlag := func(cmd *cobra.Command) {
-		cmd.PersistentFlags().BoolP(noPushLong, "", false, "do not push local branches")
+		cmd.Flags().BoolP(noPushLong, "", false, "do not push local branches")
 	}
 	readFlag := func(cmd *cobra.Command) configdomain.PushBranches {
 		value, err := cmd.Flags().GetBool(noPushLong)
