@@ -9,8 +9,16 @@ import (
 // The Logger logger logs activities of a particular component on the CLI.
 type Logger struct{}
 
-func (l Logger) Failed(failure error) {
-	fmt.Println(colors.BoldRed().Styled(fmt.Sprintf("FAILED: %v\n", failure)))
+func (l Logger) Failed(failure string) {
+	l.Log(colors.BoldRed().Styled(fmt.Sprintf("%v\n", failure)))
+}
+
+func (l Logger) Log(text string) {
+	fmt.Println(text)
+}
+
+func (l Logger) Ok() {
+	l.Success("ok")
 }
 
 func (l Logger) Start(template string, data ...interface{}) {
@@ -18,6 +26,6 @@ func (l Logger) Start(template string, data ...interface{}) {
 	fmt.Print(colors.Bold().Styled(fmt.Sprintf(template, data...)))
 }
 
-func (l Logger) Success() {
-	fmt.Println(colors.BoldGreen().Styled("ok"))
+func (l Logger) Success(message string) {
+	l.Log(colors.BoldGreen().Styled(message))
 }
