@@ -8,6 +8,7 @@ import (
 
 	"github.com/git-town/git-town/v16/internal/cli/dialog/components"
 	"github.com/git-town/git-town/v16/internal/cli/flags"
+	"github.com/git-town/git-town/v16/internal/cli/print"
 	"github.com/git-town/git-town/v16/internal/cmd/cmdhelpers"
 	"github.com/git-town/git-town/v16/internal/config"
 	"github.com/git-town/git-town/v16/internal/config/configdomain"
@@ -16,12 +17,14 @@ import (
 	"github.com/git-town/git-town/v16/internal/git/gitdomain"
 	"github.com/git-town/git-town/v16/internal/gohacks"
 	"github.com/git-town/git-town/v16/internal/gohacks/stringslice"
+	"github.com/git-town/git-town/v16/internal/hosting"
 	"github.com/git-town/git-town/v16/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v16/internal/messages"
 	"github.com/git-town/git-town/v16/internal/undo/undoconfig"
 	"github.com/git-town/git-town/v16/internal/validate"
 	configInterpreter "github.com/git-town/git-town/v16/internal/vm/interpreter/config"
 	fullInterpreter "github.com/git-town/git-town/v16/internal/vm/interpreter/full"
+	"github.com/git-town/git-town/v16/internal/vm/program"
 	"github.com/git-town/git-town/v16/internal/vm/runstate"
 	. "github.com/git-town/git-town/v16/pkg/prelude"
 	"github.com/spf13/cobra"
@@ -104,7 +107,7 @@ func executeHack(args []string, dryRun configdomain.DryRun, prototype configdoma
 // If set to convertToFeatureData, the user wants to convert an already existing branch into a feature branch.
 type hackData = Either[appendFeatureData, convertToFeatureData]
 
-// this configuration is for when "git hack" is used to make contribution, observed, or parked branches feature branches
+// this configuration is for when "git town hack" is used to make contribution, observed, or parked branches feature branches
 type convertToFeatureData struct {
 	config         config.ValidatedConfig
 	targetBranches configdomain.BranchesAndTypes
@@ -123,6 +126,7 @@ func createFeatureBranch(args createFeatureBranchArgs) error {
 		EndStashSize:          None[gitdomain.StashSize](),
 		RunProgram:            runProgram,
 		TouchedBranches:       runProgram.TouchedBranches(),
+		UndoAPIProgram:        program.Program{},
 	}
 	return fullInterpreter.Execute(fullInterpreter.ExecuteArgs{
 		Backend:                 args.backend,
@@ -204,12 +208,17 @@ func determineHackData(args []string, repo execute.OpenRepoResult, dryRun config
 			branchesToValidate = targetBranches
 		}
 	}
+	connector, err := hosting.NewConnector(repo.UnvalidatedConfig, gitdomain.RemoteOrigin, print.Logger{})
+	if err != nil {
+		return data, false, err
+	}
 	branchesAndTypes := repo.UnvalidatedConfig.Config.Value.BranchesAndTypes(branchesSnapshot.Branches.LocalBranches().Names())
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
 		Backend:            repo.Backend,
 		BranchesAndTypes:   branchesAndTypes,
 		BranchesSnapshot:   branchesSnapshot,
 		BranchesToValidate: branchesToValidate,
+		Connector:          connector,
 		DialogTestInputs:   dialogTestInputs,
 		Frontend:           repo.Frontend,
 		Git:                repo.Git,
