@@ -7,12 +7,15 @@ import (
 
 	"github.com/git-town/git-town/v16/internal/cli/dialog/components"
 	"github.com/git-town/git-town/v16/internal/cli/flags"
+	"github.com/git-town/git-town/v16/internal/cli/print"
 	"github.com/git-town/git-town/v16/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v16/internal/cmd/ship"
 	"github.com/git-town/git-town/v16/internal/config"
 	"github.com/git-town/git-town/v16/internal/config/configdomain"
 	"github.com/git-town/git-town/v16/internal/execute"
 	"github.com/git-town/git-town/v16/internal/git/gitdomain"
 	"github.com/git-town/git-town/v16/internal/gohacks/slice"
+	"github.com/git-town/git-town/v16/internal/hosting"
 	"github.com/git-town/git-town/v16/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v16/internal/messages"
 	"github.com/git-town/git-town/v16/internal/sync"
@@ -81,12 +84,13 @@ func executeKill(args []string, dryRun configdomain.DryRun, verbose configdomain
 		FinalUndoProgram:      finalUndoProgram,
 		RunProgram:            runProgram,
 		TouchedBranches:       runProgram.TouchedBranches(),
+		UndoAPIProgram:        program.Program{},
 	}
 	return fullInterpreter.Execute(fullInterpreter.ExecuteArgs{
 		Backend:                 repo.Backend,
 		CommandsCounter:         repo.CommandsCounter,
 		Config:                  data.config,
-		Connector:               None[hostingdomain.Connector](),
+		Connector:               data.connector,
 		DialogTestInputs:        data.dialogTestInputs,
 		FinalMessages:           repo.FinalMessages,
 		Frontend:                repo.Frontend,
@@ -103,18 +107,20 @@ func executeKill(args []string, dryRun configdomain.DryRun, verbose configdomain
 }
 
 type killData struct {
-	branchToKillInfo gitdomain.BranchInfo
-	branchToKillType configdomain.BranchType
-	branchWhenDone   gitdomain.LocalBranchName
-	branchesSnapshot gitdomain.BranchesSnapshot
-	config           config.ValidatedConfig
-	dialogTestInputs components.TestInputs
-	dryRun           configdomain.DryRun
-	hasOpenChanges   bool
-	initialBranch    gitdomain.LocalBranchName
-	parentBranch     Option[gitdomain.LocalBranchName]
-	previousBranch   Option[gitdomain.LocalBranchName]
-	stashSize        gitdomain.StashSize
+	branchToKillInfo         gitdomain.BranchInfo
+	branchToKillType         configdomain.BranchType
+	branchWhenDone           gitdomain.LocalBranchName
+	branchesSnapshot         gitdomain.BranchesSnapshot
+	config                   config.ValidatedConfig
+	connector                Option[hostingdomain.Connector]
+	dialogTestInputs         components.TestInputs
+	dryRun                   configdomain.DryRun
+	hasOpenChanges           bool
+	initialBranch            gitdomain.LocalBranchName
+	parentBranch             gitdomain.LocalBranchName
+	previousBranch           Option[gitdomain.LocalBranchName]
+	proposalsOfChildBranches []hostingdomain.Proposal
+	stashSize                gitdomain.StashSize
 }
 
 func determineKillData(args []string, repo execute.OpenRepoResult, dryRun configdomain.DryRun, verbose configdomain.Verbose) (data killData, exit bool, err error) {
@@ -151,6 +157,10 @@ func determineKillData(args []string, repo execute.OpenRepoResult, dryRun config
 	if branchToKill.SyncStatus == gitdomain.SyncStatusOtherWorktree {
 		return data, exit, fmt.Errorf(messages.KillBranchOtherWorktree, branchNameToKill)
 	}
+	connector, err := hosting.NewConnector(repo.UnvalidatedConfig, gitdomain.RemoteOrigin, print.Logger{})
+	if err != nil {
+		return data, false, err
+	}
 	localBranches := branchesSnapshot.Branches.LocalBranches().Names()
 	branchesAndTypes := repo.UnvalidatedConfig.Config.Value.BranchesAndTypes(branchesSnapshot.Branches.LocalBranches().Names())
 	validatedConfig, exit, err := validate.Config(validate.ConfigArgs{
@@ -158,6 +168,7 @@ func determineKillData(args []string, repo execute.OpenRepoResult, dryRun config
 		BranchesAndTypes:   branchesAndTypes,
 		BranchesSnapshot:   branchesSnapshot,
 		BranchesToValidate: gitdomain.LocalBranchNames{},
+		Connector:          connector,
 		DialogTestInputs:   dialogTestInputs,
 		Frontend:           repo.Frontend,
 		Git:                repo.Git,
@@ -189,19 +200,33 @@ func determineKillData(args []string, repo execute.OpenRepoResult, dryRun config
 	} else {
 		parentBranch = None[gitdomain.LocalBranchName]()
 	}
+	connectorOpt, err := hosting.NewConnector(repo.UnvalidatedConfig, gitdomain.RemoteOrigin, print.Logger{})
+	if err != nil {
+		return data, false, err
+	}
+	proposalsOfChildBranches := ship.LoadProposalsOfChildBranches(ship.LoadProposalsOfChildBranchesArgs{
+		ConnectorOpt:               connectorOpt,
+		Lineage:                    validatedConfig.Config.Lineage,
+		Offline:                    repo.IsOffline,
+		OldBranch:                  branchNameToKill,
+		OldBranchHasTrackingBranch: branchToKill.HasTrackingBranch(),
+	})
+	mainBranch := validatedConfig.Config.MainBranch
 	return killData{
-		branchToKillInfo: *branchToKill,
-		branchToKillType: branchTypeToKill,
-		branchWhenDone:   branchWhenDone,
-		branchesSnapshot: branchesSnapshot,
-		config:           validatedConfig,
-		dialogTestInputs: dialogTestInputs,
-		dryRun:           dryRun,
-		hasOpenChanges:   repoStatus.OpenChanges,
-		initialBranch:    initialBranch,
-		parentBranch:     parentBranch,
-		previousBranch:   previousBranchOpt,
-		stashSize:        stashSize,
+		branchToKillInfo:         *branchToKill,
+		branchToKillType:         branchTypeToKill,
+		branchWhenDone:           branchWhenDone,
+		branchesSnapshot:         branchesSnapshot,
+		config:                   validatedConfig,
+		connector:                connectorOpt,
+		dialogTestInputs:         dialogTestInputs,
+		dryRun:                   dryRun,
+		hasOpenChanges:           repoStatus.OpenChanges,
+		initialBranch:            initialBranch,
+		parentBranch:             parentBranch.GetOrElse(mainBranch),
+		previousBranch:           previousBranchOpt,
+		proposalsOfChildBranches: proposalsOfChildBranches,
+		stashSize:                stashSize,
 	}, false, nil
 }
 
@@ -230,6 +255,7 @@ func killProgram(data killData) (runProgram, finalUndoProgram program.Program) {
 func killFeatureBranch(prog, finalUndoProgram Mutable[program.Program], data killData) {
 	trackingBranchToKill, hasTrackingBranchToKill := data.branchToKillInfo.RemoteName.Get()
 	if data.branchToKillInfo.SyncStatus != gitdomain.SyncStatusDeletedAtRemote && hasTrackingBranchToKill && data.config.Config.IsOnline() {
+		ship.UpdateChildBranchProposals(prog.Value, data.proposalsOfChildBranches, data.parentBranch)
 		prog.Value.Add(&opcodes.DeleteTrackingBranch{Branch: trackingBranchToKill})
 	}
 	killLocalBranch(prog, finalUndoProgram, data)
@@ -251,11 +277,11 @@ func killLocalBranch(prog, finalUndoProgram Mutable[program.Program], data killD
 			prog.Value.Add(&opcodes.Checkout{Branch: data.branchWhenDone})
 		}
 		prog.Value.Add(&opcodes.DeleteLocalBranch{Branch: localBranchToKill})
-		if parentBranch, hasParentBranch := data.parentBranch.Get(); hasParentBranch && data.dryRun.IsFalse() {
+		if data.dryRun.IsFalse() {
 			sync.RemoveBranchFromLineage(sync.RemoveBranchFromLineageArgs{
 				Branch:  localBranchToKill,
 				Lineage: data.config.Config.Lineage,
-				Parent:  parentBranch,
+				Parent:  data.parentBranch,
 				Program: prog,
 			})
 		}
