@@ -4,12 +4,12 @@ import (
 	"os"
 	"testing"
 
-	"github.com/git-town/git-town/v15/internal/config"
-	"github.com/git-town/git-town/v15/internal/config/configdomain"
-	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	"github.com/git-town/git-town/v15/internal/git/giturl"
-	. "github.com/git-town/git-town/v15/pkg/prelude"
-	"github.com/git-town/git-town/v15/test/testruntime"
+	"github.com/git-town/git-town/v16/internal/config"
+	"github.com/git-town/git-town/v16/internal/config/configdomain"
+	"github.com/git-town/git-town/v16/internal/git/gitdomain"
+	"github.com/git-town/git-town/v16/internal/git/giturl"
+	. "github.com/git-town/git-town/v16/pkg/prelude"
+	"github.com/git-town/git-town/v16/test/testruntime"
 	"github.com/shoenig/test/must"
 )
 
@@ -75,4 +75,42 @@ func TestValidatedConfig(t *testing.T) {
 			must.Eq(t, want, repo.Config.Config.Lineage)
 		})
 	})
+
+	t.Run("RemovePerennialRoot", func(t *testing.T) {
+		t.Parallel()
+		contribution := gitdomain.NewLocalBranchName("contribution")
+		feature1 := gitdomain.NewLocalBranchName("feature1")
+		feature2 := gitdomain.NewLocalBranchName("feature2")
+		main := gitdomain.NewLocalBranchName("main")
+		observed := gitdomain.NewLocalBranchName("observed")
+		parked := gitdomain.NewLocalBranchName("parked")
+		perennial1 := gitdomain.NewLocalBranchName("perennial-1")
+		perennial2 := gitdomain.NewLocalBranchName("perennial-2")
+		prototype := gitdomain.NewLocalBranchName("prototype")
+		perennialRegexOpt, err := configdomain.ParsePerennialRegex("peren*")
+		must.NoError(t, err)
+		config := configdomain.ValidatedConfig{
+			MainBranch: gitdomain.NewLocalBranchName("main"),
+			UnvalidatedConfig: &configdomain.UnvalidatedConfig{
+				ContributionBranches: gitdomain.LocalBranchNames{contribution},
+				ObservedBranches:     gitdomain.LocalBranchNames{observed},
+				ParkedBranches:       gitdomain.LocalBranchNames{parked},
+				PerennialBranches:    gitdomain.LocalBranchNames{perennial1},
+				PerennialRegex:       perennialRegexOpt,
+				PrototypeBranches:    gitdomain.LocalBranchNames{prototype},
+			},
+		}
+		tests := map[*gitdomain.LocalBranchNames]gitdomain.LocalBranchNames{
+			{main}:                           {},
+			{perennial1, perennial2}:         {},
+			{main, feature1, feature2}:       {feature1, feature2},
+			{perennial1, feature1, feature2}: {feature1, feature2},
+			{main, feature1, observed, contribution, feature2}: {feature1, observed, contribution, feature2},
+			{main, perennial1, perennial2, feature1, feature2}: {feature1, feature2},
+		}
+		for give, want := range tests {
+			have := config.RemovePerennials(*give)
+			must.Eq(t, want, have)
+		}
+	})
 }
