@@ -510,6 +510,14 @@ func (self *Commands) RemotesUncached(querier gitdomain.Querier) (gitdomain.Remo
 	return gitdomain.NewRemotes(stringslice.Lines(out)...), nil
 }
 
+func (self *Commands) RemoveBitbucketAppPassword(runner gitdomain.Runner) error {
+	return runner.Run("git", "config", "--unset", configdomain.KeyBitbucketAppPassword.String())
+}
+
+func (self *Commands) RemoveBitbucketUsername(runner gitdomain.Runner) error {
+	return runner.Run("git", "config", "--unset", configdomain.KeyBitbucketUsername.String())
+}
+
 // RemoveGitAlias removes the given Git alias.
 func (self *Commands) RemoveGitAlias(runner gitdomain.Runner, aliasableCommand configdomain.AliasableCommand) error {
 	return runner.Run("git", "config", "--global", "--unset", aliasableCommand.Key().String())
@@ -530,6 +538,11 @@ func (self *Commands) RemoveGiteaToken(runner gitdomain.Runner) error {
 	return runner.Run("git", "config", "--unset", configdomain.KeyGiteaToken.String())
 }
 
+// RenameBranch renames the branch with the given old name to the branch with the given new name.
+func (self *Commands) RenameBranch(runner gitdomain.Runner, oldName, newName gitdomain.LocalBranchName) error {
+	return runner.Run("git", "branch", "--move", oldName.String(), newName.String())
+}
+
 // RepoStatus provides a summary of the state the current workspace is in right now: rebasing, has conflicts, has open changes, etc.
 func (self *Commands) RepoStatus(querier gitdomain.Querier) (gitdomain.RepoStatus, error) {
 	output, err := querier.QueryTrim("git", "status", "--long", "--ignore-submodules")
@@ -592,6 +605,14 @@ func (self *Commands) SHAForBranch(querier gitdomain.Querier, name gitdomain.Bra
 	return gitdomain.NewSHA(output), nil
 }
 
+func (self *Commands) SetBitbucketAppPassword(runner gitdomain.Runner, value configdomain.BitbucketAppPassword) error {
+	return runner.Run("git", "config", configdomain.KeyBitbucketAppPassword.String(), value.String())
+}
+
+func (self *Commands) SetBitbucketUsername(runner gitdomain.Runner, value configdomain.BitbucketUsername) error {
+	return runner.Run("git", "config", configdomain.KeyBitbucketUsername.String(), value.String())
+}
+
 // SetGitAlias sets the given Git alias.
 func (self *Commands) SetGitAlias(runner gitdomain.Runner, aliasableCommand configdomain.AliasableCommand) error {
 	return runner.Run("git", "config", "--global", aliasableCommand.Key().String(), "town "+aliasableCommand.String())
