@@ -3,7 +3,7 @@ package slice_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v15/internal/gohacks/slice"
+	"github.com/git-town/git-town/v16/internal/gohacks/slice"
 	"github.com/shoenig/test/must"
 )
 
@@ -20,7 +20,7 @@ func TestFirstElementOr(t *testing.T) {
 
 	t.Run("list is empty", func(t *testing.T) {
 		t.Parallel()
-		list := []string{}
+		list := []string(nil)
 		have := slice.FirstElementOr(list, "other")
 		want := "other"
 		must.EqOp(t, want, have)
