@@ -3,7 +3,7 @@ package stringslice_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
+	"github.com/git-town/git-town/v16/internal/gohacks/stringslice"
 	"github.com/shoenig/test/must"
 )
 
@@ -46,7 +46,6 @@ func TestLinesWithPrefix(t *testing.T) {
 			"two",
 		}
 		have := stringslice.LinesWithPrefix(lines, "zonk")
-		want := []string{}
-		must.Eq(t, want, have)
+		must.Len(t, 0, have)
 	})
 }
