@@ -4,11 +4,13 @@ import (
 	"errors"
 	"fmt"
 	"net/http"
+	"strconv"
 
 	"github.com/git-town/git-town/v16/internal/cli/print"
 	"github.com/git-town/git-town/v16/internal/config/configdomain"
 	"github.com/git-town/git-town/v16/internal/git/gitdomain"
 	"github.com/git-town/git-town/v16/internal/git/giturl"
+	"github.com/git-town/git-town/v16/internal/gohacks/stringslice"
 	"github.com/git-town/git-town/v16/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v16/internal/messages"
 	. "github.com/git-town/git-town/v16/pkg/prelude"
@@ -31,7 +33,7 @@ func (self Connector) FindProposal(branch, target gitdomain.LocalBranchName) (Op
 	self.log.Start(messages.APIProposalLookupStart)
 	proposalURLOverride := hostingdomain.ReadProposalOverride()
 	if len(proposalURLOverride) > 0 {
-		self.log.Success()
+		self.log.Ok()
 		if proposalURLOverride == hostingdomain.OverrideNoProposal {
 			return None[hostingdomain.Proposal](), nil
 		}
@@ -50,17 +52,43 @@ func (self Connector) FindProposal(branch, target gitdomain.LocalBranchName) (Op
 	}
 	mergeRequests, _, err := self.client.MergeRequests.ListProjectMergeRequests(self.projectPath(), opts)
 	if err != nil {
-		self.log.Failed(err)
+		self.log.Failed(err.Error())
 		return None[hostingdomain.Proposal](), err
 	}
-	self.log.Success()
 	switch len(mergeRequests) {
 	case 0:
+		self.log.Success("none")
 		return None[hostingdomain.Proposal](), nil
 	case 1:
-		return Some(parseMergeRequest(mergeRequests[0])), nil
+		proposal := parseMergeRequest(mergeRequests[0])
+		self.log.Success(strconv.Itoa(proposal.Number))
+		return Some(proposal), nil
 	default:
-		return None[hostingdomain.Proposal](), fmt.Errorf(messages.ProposalMultipleFound, len(mergeRequests), branch, target)
+		return None[hostingdomain.Proposal](), fmt.Errorf(messages.ProposalMultipleFromToFound, len(mergeRequests), branch, target)
+	}
+}
+
+func (self Connector) SearchProposals(branch gitdomain.LocalBranchName) (Option[hostingdomain.Proposal], error) {
+	self.log.Start(messages.APIParentBranchLookupStart, branch.String())
+	opts := &gitlab.ListProjectMergeRequestsOptions{
+		State:        gitlab.Ptr("opened"),
+		SourceBranch: gitlab.Ptr(branch.String()),
+	}
+	mergeRequests, _, err := self.client.MergeRequests.ListProjectMergeRequests(self.projectPath(), opts)
+	if err != nil {
+		self.log.Failed(err.Error())
+		return None[hostingdomain.Proposal](), err
+	}
+	switch len(mergeRequests) {
+	case 0:
+		self.log.Success("none")
+		return None[hostingdomain.Proposal](), nil
+	case 1:
+		proposal := parseMergeRequest(mergeRequests[0])
+		self.log.Success(proposal.Target.String())
+		return Some(proposal), nil
+	default:
+		return None[hostingdomain.Proposal](), fmt.Errorf(messages.ProposalMultipleFromFound, len(mergeRequests), branch)
 	}
 }
 
@@ -77,23 +105,28 @@ func (self Connector) SquashMergeProposal(number int, message gitdomain.CommitMe
 		ShouldRemoveSourceBranch: gitlab.Ptr(false),
 	})
 	if err != nil {
-		self.log.Failed(err)
+		self.log.Failed(err.Error())
 		return err
 	}
-	self.log.Success()
+	self.log.Ok()
 	return nil
 }
 
-func (self Connector) UpdateProposalTarget(number int, target gitdomain.LocalBranchName) error {
+func (self Connector) UpdateProposalBase(number int, target gitdomain.LocalBranchName, _ stringslice.Collector) error {
 	self.log.Start(messages.HostingGitlabUpdateMRViaAPI, number, target)
 	_, _, err := self.client.MergeRequests.UpdateMergeRequest(self.projectPath(), number, &gitlab.UpdateMergeRequestOptions{
 		TargetBranch: gitlab.Ptr(target.String()),
 	})
 	if err != nil {
-		self.log.Failed(err)
+		self.log.Failed(err.Error())
 		return err
 	}
-	self.log.Success()
+	self.log.Ok()
+	return nil
+}
+
+func (self Connector) UpdateProposalHead(number int, _ gitdomain.LocalBranchName, finalMessages stringslice.Collector) error {
+	finalMessages.Add(fmt.Sprintf(messages.APIGitLabCannotUpdateHeadBranch, number))
 	return nil
 }
 
