@@ -4,8 +4,15 @@ const (
 	UndoContinueGuidance              = "\n\nTo continue after having resolved conflicts, run \"git town continue\".\nTo go back to where you started, run \"git town undo\".\n"
 	AliasedCommands                   = "Aliased commands: %s\n"
 	ArgumentUnknown                   = "unknown argument: %q"
+	APIParentBranchLookupStart        = "Looking for parent of %s ... "
 	APIProposalLookupStart            = "Looking for proposal online ... "
-	APIProposalUpdateStart            = "updating proposal target online ..."
+	APIProposalUpdateStart            = "updating proposal online ... "
+	APIUnexpectedResultDataStructure  = "unexpected result data structure"
+	APIUpdateProposalBase             = "updating base branch of proposal %s to %s ... "
+	APIUpdateProposalHead             = "updating head branch of proposal %s to %s ... "
+	APIGitHubCannotUpdateHeadBranch   = "GitHub cannot update the head branch of pull requests.\nOnce Git Town deleted the old tracking branch,\nGitHub has therefore closed the existing pull request for this branch (#%d).\nYou have to create a new one.\n"
+	APIGitLabCannotUpdateHeadBranch   = "GitLab cannot update the source branch of merge requests:\nhttps://gitlab.com/gitlab-org/gitlab-foss/-/issues/47020\nGitLab has therefore closed the existing merge request for this branch (!%d).\nYou have to create a new one."
+	APIGiteaCannotUpdateHeadBranch    = "Gitea cannot update the head branch of pull requests.\nOnce Git Town deleted the old tracking branch,\nGitea has therefore closed the existing pull request for this branch (#%d).\nYou have to create a new one.\n"
 	BranchAlreadyExistsLocally        = "there is already a branch %q"
 	BranchAlreadyExistsRemotely       = "there is already a branch %q at the \"origin\" remote"
 	BranchAuthorMultiple              = "\nMultiple people authored the %q branch.\n\n"
@@ -106,14 +113,15 @@ END OUTPUT FROM 'git branch -vva'
 	HackTooManyArguments                  = "please provide only one branch to create"
 	HackBranchIsAlreadyFeature            = "branch %q is already a feature branch"
 	HackBranchIsNowFeature                = "branch %q is now a feature branch\n"
-	HackCannotFeatureMainBranch           = "cannot make the main branch a feature branch"
+	HackCannotFeatureMainBranch           = "you are trying to convert the main branch to a feature branch. That's not possible. If you want to create a feature branch, did you forget to add the branch name?"
 	HackCannotFeaturePerennialBranch      = "branch %q is a perennial branch and therefore be a feature branch"
-	HostingBitBucketNotImplemented        = "shipping pull requests via the Bitbucket API is currently not supported. If you need this functionality, please vote for it by opening a ticket at https://github.com/git-town/git-town/issues"
-	HostingGitlabMergingViaAPI            = "GitLab API: Merging MR !%d ... "
-	HostingGitlabUpdateMRViaAPI           = "GitLab API: Updating target branch for MR !%d to %q ... "
+	HostingBitbucketNotImplemented        = "shipping pull requests via the Bitbucket API is currently not supported. If you need this functionality, please vote for it by opening a ticket at https://github.com/git-town/git-town/issues"
+	HostingBitbucketMergingViaAPI         = "Bitbucket API: merging PR %s ... "
+	HostingGitlabMergingViaAPI            = "Merging MR !%d ... "
+	HostingGitlabUpdateMRViaAPI           = "Updating target branch for MR !%d to %q ... "
 	HostingGiteaNotImplemented            = "shipping pull requests via the Gitea API is currently not supported. If you need this functionality, please vote for it by opening a ticket at https://github.com/git-town/git-town/issues"
 	HostingGiteaUpdatePRViaAPI            = "Gitea API: Updating base branch for PR #%d to #%s"
-	HostingGithubMergingViaAPI            = "GitHub API: merging PR #%d ... "
+	HostingGithubMergingViaAPI            = "GitHub API: merging PR %s ... "
 	HostingPlatformUnknown                = "unknown hosting platform: %q"
 	InputAddOrRemove                      = `invalid argument %q. Please provide either "add" or "remove"`
 	InputYesOrNo                          = `invalid argument: %q. Please provide either "yes" or "no".\n`
@@ -149,7 +157,8 @@ END OUTPUT FROM 'git branch -vva'
 	PerennialRegex                        = "Perennial regex: %s\n"
 	PreviousCommandFinished               = "The previous Git Town command (%s) finished successfully.\n"
 	PreviousCommandProblem                = "The last Git Town command (%s) hit a problem %v ago.\n"
-	ProposalMultipleFound                 = "found %d proposals from branch %q to branch %q"
+	ProposalMultipleFromToFound           = "found %d proposals from branch %q to branch %q"
+	ProposalMultipleFromFound             = "found %d proposals for branch %q"
 	ProposalNoNumberGiven                 = "no proposal number given"
 	ProposalNoParent                      = "branch %q has no parent and can therefore not be proposed"
 	ProposalNotFoundForBranch             = "cannot determine proposal for branch %q: %w"
