@@ -1,11 +1,11 @@
 package sync
 
 import (
-	"github.com/git-town/git-town/v15/internal/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v15/internal/config/configdomain"
-	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	"github.com/git-town/git-town/v15/internal/vm/opcodes"
-	. "github.com/git-town/git-town/v15/pkg/prelude"
+	"github.com/git-town/git-town/v16/internal/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v16/internal/config/configdomain"
+	"github.com/git-town/git-town/v16/internal/git/gitdomain"
+	"github.com/git-town/git-town/v16/internal/vm/opcodes"
+	. "github.com/git-town/git-town/v16/pkg/prelude"
 )
 
 // BranchesProgram syncs all given branches.
@@ -14,11 +14,11 @@ func BranchesProgram(args BranchesProgramArgs) {
 		args.BranchProgramArgs.FirstCommitMessage = branchToSync.FirstCommitMessage
 		BranchProgram(branchToSync.BranchInfo, args.BranchProgramArgs)
 	}
-	previousbranchCandidates := gitdomain.LocalBranchNames{}
+	previousbranchCandidates := []Option[gitdomain.LocalBranchName]{args.PreviousBranch}
+	// TODO: make this a list of options
 	finalBranchCandidates := gitdomain.LocalBranchNames{args.InitialBranch}
 	if previousBranch, hasPreviousBranch := args.PreviousBranch.Get(); hasPreviousBranch {
 		finalBranchCandidates = append(finalBranchCandidates, previousBranch)
-		previousbranchCandidates = append(previousbranchCandidates, previousBranch)
 	}
 	args.Program.Value.Add(&opcodes.CheckoutFirstExisting{
 		Branches:   finalBranchCandidates,
