@@ -116,15 +116,6 @@ func (self BranchChanges) UndoProgram(args BranchChangesUndoProgramArgs) program
 		}
 	}
 
-	// remove remotely added branches
-	for _, addedRemoteBranch := range self.RemoteAdded {
-		if addedRemoteBranch.Remote() != gitdomain.RemoteUpstream {
-			result.Add(&opcodes.DeleteTrackingBranch{
-				Branch: addedRemoteBranch,
-			})
-		}
-	}
-
 	// re-create remotely removed feature branches
 	_, removedFeatureTrackingBranches := CategorizeRemoteBranchesSHAs(self.RemoteRemoved, args.Config)
 	for _, branch := range removedFeatureTrackingBranches.BranchNames() {
@@ -173,6 +164,18 @@ func (self BranchChanges) UndoProgram(args BranchChangesUndoProgramArgs) program
 		})
 	}
 
+	// undo the proposal changes now when the old and new remote branches exist
+	result.AddProgram(args.UndoAPIProgram)
+
+	// remove remotely added branches
+	for _, addedRemoteBranch := range self.RemoteAdded {
+		if addedRemoteBranch.Remote() != gitdomain.RemoteUpstream {
+			result.Add(&opcodes.DeleteTrackingBranch{
+				Branch: addedRemoteBranch,
+			})
+		}
+	}
+
 	// This must be a CheckoutIfExists opcode because this branch might not exist
 	// when a Git Town command fails, stores this undo opcode, then gets continued and deletes this branch.
 	result.Add(&opcodes.CheckoutIfExists{Branch: args.BeginBranch})
@@ -183,5 +186,6 @@ type BranchChangesUndoProgramArgs struct {
 	BeginBranch              gitdomain.LocalBranchName
 	Config                   configdomain.ValidatedConfig
 	EndBranch                gitdomain.LocalBranchName
+	UndoAPIProgram           program.Program
 	UndoablePerennialCommits []gitdomain.SHA
 }
