@@ -3,9 +3,9 @@ package undobranches_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	"github.com/git-town/git-town/v15/internal/undo/undobranches"
-	. "github.com/git-town/git-town/v15/pkg/prelude"
+	"github.com/git-town/git-town/v16/internal/git/gitdomain"
+	"github.com/git-town/git-town/v16/internal/undo/undobranches"
+	. "github.com/git-town/git-town/v16/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
@@ -58,8 +58,7 @@ func TestBranchSpan(t *testing.T) {
 				}),
 			}
 			have := branchSpan.BranchNames()
-			want := []gitdomain.BranchName{}
-			must.Eq(t, want, have)
+			must.Len(t, 0, have)
 		})
 	})
 
