@@ -1,14 +1,14 @@
 package undoconfig
 
 import (
-	"github.com/git-town/git-town/v15/internal/config/configdomain"
-	"github.com/git-town/git-town/v15/internal/undo/undodomain"
+	"github.com/git-town/git-town/v16/internal/config/configdomain"
+	"github.com/git-town/git-town/v16/internal/undo/undodomain"
 )
 
 // SingleCacheDiff provides a diff of the two given SingleCache instances.
 func SingleCacheDiff(before, after configdomain.SingleSnapshot) ConfigDiff {
 	result := ConfigDiff{
-		Added:   []configdomain.Key{},
+		Added:   nil,
 		Changed: map[configdomain.Key]undodomain.Change[string]{},
 		Removed: map[configdomain.Key]string{},
 	}
