@@ -31,10 +31,11 @@ func autoUndo(opcode shared.Opcode, runErr error, args ExecuteArgs) error {
 	lightInterpreter.Execute(lightInterpreter.ExecuteArgs{
 		Backend:       args.Backend,
 		Config:        args.Config,
+		Connector:     args.Connector,
 		FinalMessages: args.FinalMessages,
 		Frontend:      args.Frontend,
 		Git:           args.Git,
 		Prog:          undoProgram,
 	})
-	return opcode.CreateAutomaticUndoError()
+	return opcode.AutomaticUndoError()
 }
