@@ -1,4 +1,4 @@
-// Package opcode defines the individual operations that the Git Town VM can execute.
+// Package opcodes defines the individual operations that the Git Town VM can execute.
 // All opcodes implement the shared.Opcode interface.
 package opcodes
 
@@ -12,15 +12,15 @@ import (
 // undeclaredOpcodeMethods can be added to structs in this package to satisfy the shared.Opcode interface even if they don't declare all required methods.
 type undeclaredOpcodeMethods struct{}
 
-func (self *undeclaredOpcodeMethods) CreateAbortProgram() []shared.Opcode {
+func (self *undeclaredOpcodeMethods) AbortProgram() []shared.Opcode {
 	return []shared.Opcode(nil)
 }
 
-func (self *undeclaredOpcodeMethods) CreateAutomaticUndoError() error {
+func (self *undeclaredOpcodeMethods) AutomaticUndoError() error {
 	return errors.New("")
 }
 
-func (self *undeclaredOpcodeMethods) CreateContinueProgram() []shared.Opcode {
+func (self *undeclaredOpcodeMethods) ContinueProgram() []shared.Opcode {
 	return []shared.Opcode(nil)
 }
 
@@ -28,10 +28,14 @@ func (self *undeclaredOpcodeMethods) Run(_ shared.RunArgs) error {
 	return nil
 }
 
-func (self *undeclaredOpcodeMethods) ShouldAutomaticallyUndoOnError() bool {
+func (self *undeclaredOpcodeMethods) ShouldUndoOnError() bool {
 	return false
 }
 
+func (self *undeclaredOpcodeMethods) UndoExternalChangesProgram() []shared.Opcode {
+	return []shared.Opcode(nil)
+}
+
 func Lookup(opcodeType string) shared.Opcode { //nolint:ireturn
 	for _, opcode := range Types() {
 		if gohacks.TypeName(opcode) == opcodeType {
@@ -94,6 +98,7 @@ func Types() []shared.Opcode {
 		&RemoveFromPrototypeBranches{},
 		&RemoveGlobalConfig{},
 		&RemoveLocalConfig{},
+		&RenameBranch{},
 		&ResetCurrentBranch{},
 		&ResetCurrentBranchToParent{},
 		&ResetCurrentBranchToSHA{},
@@ -110,6 +115,7 @@ func Types() []shared.Opcode {
 		&StashOpenChanges{},
 		&SquashMerge{},
 		&UndoLastCommit{},
-		&UpdateProposalTarget{},
+		&UpdateProposalBase{},
+		&UpdateProposalHead{},
 	} //exhaustruct:ignore
 }
