@@ -3,11 +3,11 @@ package shared
 import (
 	"reflect"
 
-	"github.com/git-town/git-town/v15/internal/git/gitdomain"
+	"github.com/git-town/git-town/v16/internal/git/gitdomain"
 )
 
 func BranchesInOpcode(code Opcode) []gitdomain.BranchName {
-	result := []gitdomain.BranchName{}
+	var result []gitdomain.BranchName
 	valueOfSelf := reflect.ValueOf(code).Elem()
 	typeOfSelf := valueOfSelf.Type()
 	for i := range valueOfSelf.NumField() {
