@@ -142,6 +142,10 @@ func TestLoadSave(t *testing.T) {
 				&opcodes.RemoveLocalConfig{
 					Key: configdomain.KeyOffline,
 				},
+				&opcodes.RenameBranch{
+					NewName: "new",
+					OldName: "old",
+				},
 				&opcodes.ResetCurrentBranchToSHA{
 					Hard:        true,
 					MustHaveSHA: gitdomain.NewSHA("222222"),
@@ -175,9 +179,15 @@ func TestLoadSave(t *testing.T) {
 				},
 				&opcodes.StageOpenChanges{},
 				&opcodes.StashOpenChanges{},
-				&opcodes.UpdateProposalTarget{
+				&opcodes.UpdateProposalBase{
 					ProposalNumber: 123,
 					NewTarget:      gitdomain.NewLocalBranchName("new-target"),
+					OldTarget:      gitdomain.NewLocalBranchName("old-target"),
+				},
+				&opcodes.UpdateProposalHead{
+					ProposalNumber: 123,
+					NewTarget:      gitdomain.NewLocalBranchName("new-target"),
+					OldTarget:      gitdomain.NewLocalBranchName("old-target"),
 				},
 			},
 			TouchedBranches: []gitdomain.BranchName{"branch-1", "branch-2"},
@@ -457,6 +467,13 @@ func TestLoadSave(t *testing.T) {
       },
       "type": "RemoveLocalConfig"
     },
+    {
+      "data": {
+        "NewName": "new",
+        "OldName": "old"
+      },
+      "type": "RenameBranch"
+    },
     {
       "data": {
         "Hard": true,
@@ -526,15 +543,25 @@ func TestLoadSave(t *testing.T) {
     {
       "data": {
         "NewTarget": "new-target",
+        "OldTarget": "old-target",
         "ProposalNumber": 123
       },
-      "type": "UpdateProposalTarget"
+      "type": "UpdateProposalBase"
+    },
+    {
+      "data": {
+        "NewTarget": "new-target",
+        "OldTarget": "old-target",
+        "ProposalNumber": 123
+      },
+      "type": "UpdateProposalHead"
     }
   ],
   "TouchedBranches": [
     "branch-1",
     "branch-2"
   ],
+  "UndoAPIProgram": [],
   "UndoablePerennialCommits": null,
   "UnfinishedDetails": {
     "CanSkip": true,
